<?php
/**
 * Cart totals
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart-totals.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.3.6
 */
if ( !defined( 'ABSPATH' ) ) {
	exit;
}
?>
<div class="totals cart_totals <?php echo ( WC()->customer->has_calculated_shipping() ) ? 'calculated_shipping' : ''; ?>">

<?php do_action( 'woocommerce_before_cart_totals' ); ?>

    <h2 class="cart_total_title"><?php _e( 'Cart totals', 'daydream' ); ?></h2>

	<table cellspacing="0" class="table totals-table shop_table shop_table_responsive">

		<tr class="cart-subtotal">
			<td><h5 class="m-0"><?php _e( 'Subtotal', 'daydream' ); ?></h5></td>
			<td data-title="<?php esc_attr_e( 'Subtotal', 'daydream' ); ?>"><h5 class="m-0 color-gray text-right"><?php wc_cart_totals_subtotal_html(); ?></h5></td>
		</tr>

<?php foreach ( WC()->cart->get_coupons() as $code => $coupon ) : ?>
			<tr class="cart-discount coupon-<?php echo esc_attr( sanitize_title( $code ) ); ?>">
				<td><h5 class="m-0"><?php wc_cart_totals_coupon_label( $coupon ); ?></h5></td>
				<td data-title="<?php echo esc_attr( wc_cart_totals_coupon_label( $coupon, false ) ); ?>"><h5 class="m-0 color-gray text-right"><?php wc_cart_totals_coupon_html( $coupon ); ?></h5></td>
			</tr>
<?php endforeach; ?>

		<?php if ( WC()->cart->needs_shipping() && WC()->cart->show_shipping() ) : ?>

			<?php do_action( 'woocommerce_cart_totals_before_shipping' ); ?>

			<?php wc_cart_totals_shipping_html(); ?>

			<?php do_action( 'woocommerce_cart_totals_after_shipping' ); ?>

		<?php elseif ( WC()->cart->needs_shipping() && 'yes' === get_option( 'woocommerce_enable_shipping_calc' ) ) : ?>

			<tr class="shipping">
				<td><h5 class="m-0"><?php _e( 'Shipping', 'daydream' ); ?></h5></td>
				<td data-title="<?php esc_attr_e( 'Shipping', 'daydream' ); ?>"><h5 class="m-0 color-gray text-right"><?php woocommerce_shipping_calculator(); ?></h5></td>
			</tr>

<?php endif; ?>

		<?php foreach ( WC()->cart->get_fees() as $fee ) : ?>
			<tr class="fee">
				<td><h5 class="m-0"><?php echo esc_html( $fee->name ); ?></h5></td>
				<td data-title="<?php echo esc_attr( $fee->name ); ?>"><h5 class="m-0 color-gray text-right"><?php wc_cart_totals_fee_html( $fee ); ?></h5></td>
			</tr>
<?php endforeach; ?>

		<?php
		if ( wc_tax_enabled() && !WC()->cart->display_prices_including_tax() ) :
			$taxable_address = WC()->customer->get_taxable_address();
			$estimated_text	 = WC()->customer->is_customer_outside_base() && !WC()->customer->has_calculated_shipping() ? sprintf( ' <small>' . __( '(estimated for %s)', 'daydream' ) . '</small>', WC()->countries->estimated_for_prefix( $taxable_address[ 0 ] ) . WC()->countries->countries[ $taxable_address[ 0 ] ] ) : '';

			if ( 'itemized' === get_option( 'woocommerce_tax_total_display' ) ) :
				?>
				<?php foreach ( WC()->cart->get_tax_totals() as $code => $tax ) : ?>
					<tr class="tax-rate tax-rate-<?php echo esc_attr( sanitize_title( $code ) ); ?>">
						<td><h5 class="m-0"><?php echo esc_html( $tax->label ) . $estimated_text; ?></h5></td>
						<td data-title="<?php echo esc_attr( $tax->label ); ?>"><h5 class="m-0 color-gray text-right"><?php echo wp_kses_post( $tax->formatted_amount ); ?></h5></td>
					</tr>
		<?php endforeach; ?>
			<?php else : ?>
				<tr class="tax-total">
					<td><h5 class="m-0"><?php echo esc_html( WC()->countries->tax_or_vat() ) . $estimated_text; ?></h5></td>
					<td data-title="<?php echo esc_attr( WC()->countries->tax_or_vat() ); ?>"><h5 class="m-0 color-gray text-right"><?php wc_cart_totals_taxes_total_html(); ?></h5></td>
				</tr>
	<?php endif; ?>
		<?php endif; ?>

		<?php do_action( 'woocommerce_cart_totals_before_order_total' ); ?>

		<tr class="order-total">
			<td><h4 class="m-0"><?php _e( 'Total', 'daydream' ); ?></h4></td>
			<td data-title="<?php esc_attr_e( 'Total', 'daydream' ); ?>"><h4 class="m-0 text-right"><?php wc_cart_totals_order_total_html(); ?></h4></td>
		</tr>

<?php do_action( 'woocommerce_cart_totals_after_order_total' ); ?>

	</table>

<?php do_action( 'woocommerce_after_cart_totals' ); ?>

</div>
